function CharacterCustomizationManager:get_all_parts_indexed_filtered(part_type, nationality, owned_only)
	local data = tweak_data.character_customization:get_all_parts_indexed(part_type)
	local result = {}
	local owned_customizations = self:get_all_owned_customizations()
	local unlocked_customizations = tweak_data.dlc:get_unlocked_customizations()
	local counter = 1

	for index, part_data in pairs(data) do
		local new_data = clone(part_data)

		Application:trace("[CharacterCustomizationManager:get_all_parts_indexed_filtered] new_data ", inspect(new_data))

		if (not owned_only or owned_customizations[new_data.key_name]) then
			local should_show = true

			if not owned_customizations[new_data.key_name] then
				if new_data.dlc and not unlocked_customizations[new_data.key_name] then
					if not new_data.dlc_show_if_locked then
						should_show = false
					end

					new_data.locked = managers.character_customization.LOCKED_DLC_SPECIFIC
					new_data.status = RaidGUIControlGridItem.STATUS_LOCKED_DLC
				elseif new_data.gold_price then
					new_data.locked = managers.character_customization.LOCKED_GOLD_NOT_OWNED
					new_data.status = RaidGUIControlGridItem.STATUS_PURCHASABLE
				else
					new_data.locked = managers.character_customization.LOCKED_NOT_OWNED
					new_data.status = RaidGUIControlGridItem.STATUS_LOCKED
				end
			else
				new_data.status = RaidGUIControlGridItem.STATUS_OWNED_OR_PURCHASED
			end

			if should_show then
				new_data.breadcrumb = {}
				local breadcrumb_category = nil

				for i, category in pairs(BreadcrumbManager.CATEGORY_CHARACTER_CUSTOMIZATION.subcategories) do
					if category.identifier == new_data.part_type then
						breadcrumb_category = category

						break
					end
				end

				new_data.breadcrumb.category = breadcrumb_category
				new_data.breadcrumb.identifiers = {}

				table.insert(new_data.breadcrumb.identifiers, new_data.nationalities[1])
				table.insert(new_data.breadcrumb.identifiers, new_data.key_name)
				table.insert(result, new_data)
			end
		end
	end

	result = self:_sort_by_unlocked(result)

	return result
end